@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.15';
+$VERSION = '0.16';
 
 =encoding utf8
 
@@ -70,10 +70,55 @@ my %debian = (
     '3.0'       => 'woody',
     '3.1'       => 'sarge',
     '4.0'       => 'etch',
+    '4.1'       => 'etch',
+    '4.2'       => 'etch',
+    '4.3'       => 'etch',
+    '4.4'       => 'etch',
+    '4.5'       => 'etch',
+    '4.6'       => 'etch',
+    '4.7'       => 'etch',
+    '4.8'       => 'etch',
+    '4.9'       => 'etch',
     '5.0'       => 'lenny',
+    '5.1'       => 'lenny',
+    '5.2'       => 'lenny',
+    '5.3'       => 'lenny',
+    '5.4'       => 'lenny',
+    '5.5'       => 'lenny',
+    '5.6'       => 'lenny',
+    '5.7'       => 'lenny',
+    '5.8'       => 'lenny',
+    '5.9'       => 'lenny',
+    '5.10'      => 'lenny',
     '6.0'       => 'squeeze',
+    '6.1'       => 'squeeze',
+    '6.2'       => 'squeeze',
+    '6.3'       => 'squeeze',
+    '6.4'       => 'squeeze',
+    '6.5'       => 'squeeze',
+    '6.6'       => 'squeeze',
+    '6.7'       => 'squeeze',
+    '6.8'       => 'squeeze',
+    '6.9'       => 'squeeze',
+    '6.10'      => 'squeeze',
     '7.0'       => 'wheezy',
+    '7.1'       => 'wheezy',
+    '7.2'       => 'wheezy',
+    '7.3'       => 'wheezy',
+    '7.4'       => 'wheezy',
+    '7.5'       => 'wheezy',
+    '7.6'       => 'wheezy',
+    '7.7'       => 'wheezy',
+    '7.8'       => 'wheezy',
+    '7.9'       => 'wheezy',
+    '7.10'      => 'wheezy',
     '8.0'       => 'jessie',
+    '8.1'       => 'jessie',
+    '8.2'       => 'jessie',
+    '8.3'       => 'jessie',
+    '8.4'       => 'jessie',
+    '9.0'       => 'stretch',
+    '10.0'      => 'buster',
 );
 
 # Fedora naming scheme is no longer used:
@@ -267,6 +312,17 @@ my %scientific = (
     '6.1'       => 'Carbon',
     '6.2'       => 'Carbon',
     '6.3'       => 'Carbon',
+    '6.4'       => 'Carbon',
+    '6.5'       => 'Carbon',
+    '6.6'       => 'Carbon',
+    '6.7'       => 'Carbon',
+    '6.8'       => 'Carbon',
+    '6.9'       => 'Carbon',
+    '6.10'      => 'Carbon',
+    '6.11'      => 'Carbon',
+    '7.0'       => 'Nitrogen',
+    '7.1'       => 'Nitrogen',
+    '7.2'       => 'Nitrogen',
 );
 
 # http://en.wikipedia.org/wiki/Ubuntu_%28operating_system%29#Releases
@@ -292,6 +348,9 @@ my %ubuntu = (
     '13.10'     => 'Saucy Salamander',
     '14.04'     => 'Trusty Tahr',
     '14.10'     => 'Utopic Unicorn',
+    '15.04'     => 'Vivid Vervet',
+    '15.10'     => 'Wily Werewolf',
+    '16.04'     => 'Xenial Xerus',
 );
 
 my %distributions = (
@@ -521,7 +580,7 @@ RT Queue: http://rt.cpan.org/Public/Dist/Display.html?Name=Devel-Platform-Info
 
 =head1 COPYRIGHT & LICENSE
 
-  Copyright (C) 2010-2014 Birmingham Perl Mongers
+  Copyright (C) 2010-2016 Birmingham Perl Mongers
 
   This distribution is free software; you can redistribute it and/or
   modify it under the Artistic License 2.0.
